# servc-etl-python

Typings for ETL using Serv-C.

[![PyPI version](https://badge.fury.io/py/servcetl.svg)](https://pypi.org/project/servcetl/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/servcetl)](https://pypi.org/project/servcetl/)
